pub enum FeatureId {
Vertex(u32),
Edge(u32),
Face(u32),
Unknown,
}Expand description
An identifier of a feature of a convex polyhedron.
This identifier is shape-dependent and is such that it allows an efficient retrieval of the geometric information of the feature.
Variants
Vertex(u32)
Shape-dependent identifier of a vertex.
Edge(u32)
Shape-dependent identifier of an edge.
Face(u32)
Shape-dependent identifier of a face.
Unknown
Unknown identifier.
Implementations
Sourceimpl FeatureId
impl FeatureId
Sourcepub fn unwrap_vertex(self) -> u32
pub fn unwrap_vertex(self) -> u32
Revries the value of the identifier if self is a vertex.
Sourcepub fn unwrap_edge(self) -> u32
pub fn unwrap_edge(self) -> u32
Revries the value of the identifier if self is an edge.
Sourcepub fn unwrap_face(self) -> u32
pub fn unwrap_face(self) -> u32
Retrieves the value of the identifier if self is a face.