pub struct Compound { /* private fields */ }Expand description
A compound shape with an aabb bounding volume.
A compound shape is a shape composed of the union of several simpler shape. This is the main way of creating a concave shape from convex parts. Each parts can have its own delta transformation to shift or rotate it with regard to the other shapes.
Implementations
Sourceimpl Compound
impl Compound
Sourcepub fn shapes(&self) -> &[(Isometry<f64>, SharedShape)]
pub fn shapes(&self) -> &[(Isometry<f64>, SharedShape)]
The shapes of this compound shape.
Sourcepub fn local_aabb(&self) -> &Aabb
pub fn local_aabb(&self) -> &Aabb
The Aabb of this compound in its local-space.
Sourcepub fn local_bounding_sphere(&self) -> BoundingSphere
pub fn local_bounding_sphere(&self) -> BoundingSphere
The bounding-sphere of this compound in its local-space.